@@ -5,32 +5,28 @@ package inc::MBX::Alien::FLTK::Platform::Windows;
     use Carp qw[];
     use Config qw[%Config];
     use lib '../../../../../';
-    use inc::MBX::Alien::FLTK::Utility qw[_o _a _rel _abs can_run _path];
+    use inc::MBX::Alien::FLTK::Utility qw[_o _a _rel _abs can_run];
     use inc::MBX::Alien::FLTK;
     use base 'inc::MBX::Alien::FLTK::Base';
     $|++;
 
     sub configure {
-        my ($self, @args) = @_;
+        my ($self) = @_;
         $self->quiet(1);
-        $self->SUPER::configure()
-            if !grep {m[no_base]} @args;    # Get basic config data
+        $self->SUPER::configure();
         $self->notes(  ldflags => ' -mwindows '
                      . $self->notes('ldflags')
                      . ' -lmsimg32 -lole32 -luuid -lcomctl32 -lwsock32');
         $self->notes('cxxflags' => '-mwindows -DWIN32 -Wno-non-virtual-dtor '
                      . $self->notes('cxxflags'));
-        $self->notes(
-                   'cflags' => '-mwindows -DWIN32 ' . $self->notes('cflags'));
 
         #$self->notes('define')->{'HAVE_DIRENT_H'}   = undef;
         #$self->notes('define')->{'HAVE_SYS_NDIR_H'} = undef;
         #$self->notes('define')->{'HAVE_SYS_DIR_H'}  = undef;
         #$self->notes('define')->{'HAVE_NDIR_H'}     = undef;
         $self->notes('define')->{'HAVE_SCANDIR'} = undef;
-        $self->notes('define')->{'HAVE_DIRENT'}  = 0;
     GL: {
-            last if grep {m[^no_gl$]} @args;
+            last GL if !$self->find_h('GL/gl.h');
             print 'Testing GL Support... ';
             if (!$self->assert_lib({lib => 'opengl32', header => 'GL/gl.h'}))
             {   print "not okay\n";
@@ -39,12 +35,11 @@ package inc::MBX::Alien::FLTK::Platform::Windows;
                                message => 'OpenGL libs were not found'
                               }
                 );
-                $self->notes(GL => '');
+                last GL;
                 for my $lib (keys %{$self->notes('libs_source')}) {
                     $self->notes('libs_source')->{$lib}{'disabled'}++
-                        if $lib =~ m[gl]i;
+                        if $lib =~ m[gl$]i;
                 }
-                last GL;
             }
             print "okay\n";
             $self->notes('define')->{'HAVE_GL'} = 1;
@@ -58,12 +53,11 @@ package inc::MBX::Alien::FLTK::Platform::Windows;
                                message => 'OpenGLU32 libs were not found'
                               }
                 );
-                $self->notes(GL => '');
+                last GL;
                 for my $lib (keys %{$self->notes('libs_source')}) {
                     $self->notes('libs_source')->{$lib}{'disabled'}++
-                        if $lib =~ m[gl]i;
+                        if $lib =~ m[gl$]i;
                 }
-                last GL;
             }
             else {
                 $self->notes('define')->{'HAVE_GL_GLU_H'} = 1;
